@@ -1,4 +1,4 @@
-# $Id: SQL.pm 42404 2014-10-20 14:36:37Z anton $
+# $Id: SQL.pm 42415 2014-10-21 11:10:07Z anton $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/pwdmodifier/libpwdmodifier/lib/UvT/PwdModifier/SQL.pm $
 #
 # Er wordt door deze app geschreven naar adb123, die wordt eens in het uur ofzo gelezen
@@ -67,7 +67,7 @@ use Spiffy -Base;
 use DBI;
 use Data::Dumper;
 
-field 'debug' => 0;
+field debug => 0;
 field 'db';
 field 'dsn', -init => 'die "no dsn configured\n"';
 field 'user', -init => 'die "no db user configured\n"';
